SpawnCommand

Trait SpawnCommand 

pub trait SpawnCommand {
    // Required method
    fn spawn(self) -> Result<SpawnedCommand>;
}
Available on crate feature process only.
Trait used by objects that can spawn a command suitable for use with a ProcessStream.

Required Methods

fn spawn(self) -> Result<SpawnedCommand>

Spawns the command with the stdout and stderr handles configured appropriately.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors